==> jc-1.4.0.tar.gz: soot/SceneTransformer.h <==
// public abstract class soot.SceneTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header soot_Transformer

#include "soot/Transformer.h"

#ifndef _JC_soot_SceneTransformer_H_
#define _JC_soot_SceneTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_SceneTransformer$sub_refs	_jc_soot_SceneTransformer$sub_refs;
typedef struct _jc_soot_SceneTransformer$sub_nonrefs	_jc_soot_SceneTransformer$sub_nonrefs;
typedef struct _jc_soot_SceneTransformer$refs	_jc_soot_SceneTransformer$refs;
typedef struct _jc_soot_SceneTransformer$nonrefs	_jc_soot_SceneTransformer$nonrefs;
typedef struct _jc_soot_SceneTransformer$object	_jc_soot_SceneTransformer$object;

typedef const struct _jc_soot_SceneTransformer$vmethods	_jc_soot_SceneTransformer$vmethods;
typedef const struct _jc_soot_SceneTransformer$vtable	_jc_soot_SceneTransformer$vtable;
typedef const struct _jc_soot_SceneTransformer$vtype	_jc_soot_SceneTransformer$vtype;

// Constructors
extern void _jc_soot_SceneTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_SceneTransformer$object *);

// Virtual methods
extern void _jc_soot_SceneTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_SceneTransformer$method$transform$7c8054c0d573bf7e(_jc_env *, struct _jc_soot_SceneTransformer$object *);
extern void _jc_soot_SceneTransformer$method$transform$b68c71a5b52c97d4(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_SceneTransformer$method$transform$94afae46cb7667a8(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_SceneTransformer$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$7c8054c0d573bf7e;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$b68c71a5b52c97d4;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$94afae46cb7667a8;

// Virtual methods structure
struct _jc_soot_SceneTransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*transform$7c8054c0d573bf7e)(_jc_env *, struct _jc_soot_SceneTransformer$object *);
	void	(*transform$b68c71a5b52c97d4)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *);
	void	(*transform$94afae46cb7667a8)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_SceneTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
};

// Vtype
struct _jc_soot_SceneTransformer$vtype {
	_jc_type			type;
	_jc_soot_SceneTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_SceneTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_SceneTransformer$refs {
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_SceneTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_SceneTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
};

// Object instance structure
struct _jc_soot_SceneTransformer$object {
	_jc_soot_SceneTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_SceneTransformer$vtype	*vtype;
	_jc_soot_SceneTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_SceneTransformer$vtype _jc_soot_SceneTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_SceneTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_SceneTransformer$class_object;

#endif	/* _JC_soot_SceneTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/SceneTransformer.h <==
// public abstract class soot.SceneTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header soot_Transformer

#include "soot/Transformer.h"

#ifndef _JC_soot_SceneTransformer_H_
#define _JC_soot_SceneTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_SceneTransformer$sub_refs	_jc_soot_SceneTransformer$sub_refs;
typedef struct _jc_soot_SceneTransformer$sub_nonrefs	_jc_soot_SceneTransformer$sub_nonrefs;
typedef struct _jc_soot_SceneTransformer$refs	_jc_soot_SceneTransformer$refs;
typedef struct _jc_soot_SceneTransformer$nonrefs	_jc_soot_SceneTransformer$nonrefs;
typedef struct _jc_soot_SceneTransformer$object	_jc_soot_SceneTransformer$object;

typedef const struct _jc_soot_SceneTransformer$vmethods	_jc_soot_SceneTransformer$vmethods;
typedef const struct _jc_soot_SceneTransformer$vtable	_jc_soot_SceneTransformer$vtable;
typedef const struct _jc_soot_SceneTransformer$vtype	_jc_soot_SceneTransformer$vtype;

// Constructors
extern void _jc_soot_SceneTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_SceneTransformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_SceneTransformer$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_SceneTransformer$method$transform$7c8054c0d573bf7e(_jc_env *, struct _jc_soot_SceneTransformer$object *) _JC_JCNI_ATTR;
extern void _jc_soot_SceneTransformer$method$transform$b68c71a5b52c97d4(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_SceneTransformer$method$transform$94afae46cb7667a8(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_SceneTransformer$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$7c8054c0d573bf7e;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$b68c71a5b52c97d4;
extern _jc_method _jc_soot_SceneTransformer$method_info$transform$94afae46cb7667a8;

// Virtual methods structure
struct _jc_soot_SceneTransformer$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*transform$7c8054c0d573bf7e)(_jc_env *, struct _jc_soot_SceneTransformer$object *) _JC_JCNI_ATTR;
	void	(*transform$b68c71a5b52c97d4)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*transform$94afae46cb7667a8)(_jc_env *, struct _jc_soot_SceneTransformer$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_SceneTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
};

// Vtype
struct _jc_soot_SceneTransformer$vtype {
	_jc_type			type;
	_jc_soot_SceneTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_SceneTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_SceneTransformer$refs {
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_SceneTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_SceneTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
};

// Object instance structure
struct _jc_soot_SceneTransformer$object {
	_jc_soot_SceneTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_SceneTransformer$vtype	*vtype;
	_jc_soot_SceneTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_SceneTransformer$vtype _jc_soot_SceneTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_SceneTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_SceneTransformer$class_object;

#endif	/* _JC_soot_SceneTransformer_H_ */
